
clear
set more off
set matsize 5000


// create or overwrite output file in ascii format

capture log close
log using logfiles/bma_prelim.log, replace    


********************************************************************************
*	
*	This program checks for GCMs that have negative correlations with
*	observations and tests spatial AC, then runs nested and non-nested tests
*	
********************************************************************************
clear

insheet using data/climate_bma.csv
drop if cru3v==.
*

sum cru3v msu 
pwcorr cru3v msu

sum ms1-ms22
local dep cru3v
local Gm "msu slp dry dslp water abslat aorv naorv pdorv soirv"		// Geographic Variables
local Zg "ms1-ms22"													// Climate Model Outputs
local Xb "g e x p m y c"											// Socioeconomic Variables


matrix beta_uni=J(22,1,0)												// will record coeff signs
matrix beta_multi=J(22,1,0)
matrix nest_pval=J(22,1,0)

//	TABLE 1
sum cru3v msu dry water abslat aorv naorv pdorv soirv g e x p m y c 

//	TABLE 2
sum ms1-ms22


********************************************************************************
*
*	TABLE 3: COMPUTE SIGNS OF MODEL COEFFS AND SELECT FOR RETENTION
*	BASED ON NON-NEG COEFF IN UNIVARIATE AND MULTIVARIATE REGRESSIONS	
*
********************************************************************************

forvalues i = 1/22		{

	display "i="`i'

	qui reg `dep' ms`i' , robust cluster(g) 
		qui lincom ms`i'
			matrix beta_uni[`i',1]=r(estimate)

	qui reg `dep' ms`i' `Gm' `Xb' ,robust cluster(g)
		qui lincom ms`i'
			matrix beta_multi[`i',1]=r(estimate)
		qui test ms`i'
			matrix nest_pval[`i',1]=r(p)			// p-value of zero restriction
		

		if (`i'==22) 		{				// printout results
			svmat beta_uni
				rename beta_uni1 beta_uni
			svmat beta_multi
				rename beta_multi1 beta_multi
			svmat nest_pval
				rename nest_pval1 nest_pval
			generate keep_m=(beta_multi>0)
			generate keep_u=(beta_uni>0)
			generate keep_gcm=keep_u*keep_m
			generate p_drop_gcm=keep_gcm*nest_pval+(1-keep_gcm)

	//			TABLE 3
			list beta_uni beta_multi keep_gcm p_drop_gcm in 1/22
							}

					}

*
*	On this basis keep models 2,3,10,11,13,14,16-21
local Zg "ms2 ms3 ms10 ms11 ms13 ms14 ms16 ms17 ms18 ms19 ms20 ms21"



********************************************************************************
*
* 	NESTED AND NON-NESTED TESTS
*
********************************************************************************

//	TABLE 4

matrix Table4=J(26,8,0)

*	Test Combinations of Explanatory Models
	reg `dep' `Zg' , robust cluster(g)
		testparm `Zg'
			matrix Table4[1,1]=r(F)
			matrix Table4[1,2]=r(p)

	reg `dep' `Gm' `Zg' , robust cluster(g)
		testparm `Zg'
			matrix Table4[2,1]=r(F)
			matrix Table4[2,2]=r(p)
		testparm `Gm'
			matrix Table4[2,5]=r(F)
			matrix Table4[2,6]=r(p)
			
	reg `dep' `Zg' `Xb' , robust cluster(g)
		testparm `Zg'
			matrix Table4[3,1]=r(F)
			matrix Table4[3,2]=r(p)
		testparm `Xb' 
			matrix Table4[3,3]=r(F)
			matrix Table4[3,4]=r(p)
			
	reg `dep' `Gm' `Zg' `Xb' , robust cluster(g)
		testparm `Zg'
			matrix Table4[26,1]=r(F)
			matrix Table4[26,2]=r(p)
		testparm `Xb' 
			matrix Table4[26,3]=r(F)
			matrix Table4[26,4]=r(p)
		testparm `Gm'
			matrix Table4[26,5]=r(F)
			matrix Table4[26,6]=r(p)
		testparm `Gm' `Xb'				// Test if M1 Encomp M4
			matrix Table4[26,7]=r(F)
			matrix Table4[26,8]=r(p)
	

//	ROWS 4-25
forvalues i = 1/22	{
	reg `dep' `Gm' ms`i' `Xb' , robust cluster(g)
		test ms`i' 
			matrix Table4[3+`i',1]=r(F)
			matrix Table4[3+`i',2]=r(p)
		testparm `Xb' 
			matrix Table4[3+`i',3]=r(F)
			matrix Table4[3+`i',4]=r(p)
		testparm `Gm'
			matrix Table4[3+`i',5]=r(F)
			matrix Table4[3+`i',6]=r(p)
		testparm `Gm' `Xb'				// Test if M1 Encomp M4
			matrix Table4[3+`i',7]=r(F)
			matrix Table4[3+`i',8]=r(p)
					
*	Print out results
	if (`i'==22) 		{

			svmat Table4
				rename Table41 Zgamma_F
				rename Table42 Zgamma_pr
				rename Table43 Xbeta_F
				rename Table44 Xbeta_pr
				rename Table45 Gmu_F
				rename Table46 Gmu_pr
				rename Table47 M1_Enc_M4_F
				rename Table48 M1_Enc_M4_pr

* TABLE 4
			list Zgamma_F Zgamma_pr Xbeta_F Xbeta_pr Gmu_F Gmu_pr M1_Enc_M4_F M1_Enc_M4_pr in 1/26, div
						}
					}			
			
//	TABLE 5
matrix Table5=J(23,4,0)

//	ROW 23
*	NON-NESTED TEST ALL-GCM NULL
qui reg `dep' `Gm' `Zg' , robust cluster(g)
	predict pzy
	reg `dep' `Gm' `Xb' pzy , robust cluster(g)
		test pzy=0	// GCM has no explanatory power
			matrix Table5[23,1]=r(p)
		test pzy=1	// GCM has all explanatory power
			matrix Table5[23,2]=r(p)
		drop pzy 

*	NON-NESTED TEST, SOCIOECON NULL
qui reg `dep' `Gm' `Xb' , robust cluster(g)
	predict pzy
	reg `dep' `Gm' `Zg'  pzy , robust cluster(g)
		test pzy=0	// SOCIOECON has no explanatory power
			matrix Table5[23,3]=r(p)
		test pzy=1	// SOCIOECON has all explanatory power
			matrix Table5[23,4]=r(p)
		drop pzy 

//	ROWS 1-22
forvalues i = 1/22	{

*	Test a: GCM null
	 qui reg `dep' ms`i' `Gm' 
		predict pzy
	 display "model " `i'
	 qui reg `dep' `Gm' `Xb' pzy , robust cluster(g)
		qui test pzy=0	
			matrix Table5[`i',1]=r(p)
		qui test pzy=1		
			matrix Table5[`i',2]=r(p)
		drop pzy 


*	Test b: SOCIOECON null
	qui reg `dep' `Gm' `Xb' 
		predict pxy
	qui reg `dep' ms`i' `Gm' pxy , robust cluster(g)
		qui test pxy=0		
			matrix Table5[`i',3]=r(p)
		qui test pxy=1		
			matrix Table5[`i',4]=r(p)
		drop pxy

*	Print out results
	if (`i'==22) 		{

			svmat Table5
				rename Table51 GCM_0 
				rename Table52 GCM_1 
				rename Table53 SOC_0 
				rename Table54 SOC_1 

* TABLE 5
			list GCM_0 GCM_1 SOC_0 SOC_1 in 1/23, div

* TABLE 6
			sum  GCM_0 GCM_1 SOC_0 SOC_1 if keep_gcm==1
					}


				}


//

********************************************************************************
*
*		TABLE 8: BMA-Optimal vs Full Specification
*
********************************************************************************

reg `dep' `Gm' `Xb' , robust cluster(g)
	est store soc 
reg `dep' `Gm' e g c ms11 ms13 ms19, robust cluster(g)
	predict clim
	est store bma
	replace clim=clim-_b[g]*g-_b[e]*e-_b[c]*c+_b[g]*.36762+_b[e]*144.2 // filter out socio contamination
	sum `dep' clim
reg `dep' `Gm' `Xb' `Zg' , robust cluster(g)
	est store full

	/* Test to see minimal PIP for encompassing */
	test c ms19 ms18 ms21 ms10 ms14 ms20 p y m ms2 ms16 ms3 ms17 x 		// PIP >0.5
	test   ms19 ms18 ms21 ms10 ms14 ms20 p y m ms2 ms16 ms3 ms17 x 		// PIP >0.24
	test        ms18 ms21 ms10 ms14 ms20 p y m ms2 ms16 ms3 ms17 x		// PIP >0.21
	test             ms21 ms10 ms14 ms20 p y m ms2 ms16 ms3 ms17 x		// PIP >0.10
	test                  ms10 ms14 ms20 p y m ms2 ms16 ms3 ms17 x		// PIP >0.08
	test                            ms20 p y m ms2 ms16 ms3 ms17 x		// PIP >0.07
	test                                       ms2 ms16 ms3 ms17 x		// PIP >0.05

	
est table full soc bma, stat(N r2) b(%9.4f) p(%9.3f) style(columns)


********************************************************************************
*
*		Verify spatial AC in errors removed
*
********************************************************************************

//		GENERATE Row-Standardized MATRIX AND EIGENVALUES FOR REG COMMANDS
	spatwmat using data/Wcru3.dta , name(W1) eigenval(E1) standardize

	qui reg cru3v msu slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c , robust cluster(g)
		spatdiag, weights(W1)


forvalues i = 1/22	{

	qui reg cru3v ms`i' msu slp dry dslp water abslat aorv naorv pdorv soirv g e x p m y c , robust cluster(g)
		spatdiag, weights(W1)

				}


*

********************************************************************************
*
*		Plot Figure 1
*
********************************************************************************

*
*	Use data from http://huebler.info/2009/world_adm0.zip to generate world map
*	Unzip the shp and dbf files and put in data folder
*
keep lat lon				// save lat & lon points
save data/latlon.dta, replace

shp2dta using data/world_adm0, coordinates(data/world-c) database(data/world-d) genid(id1) replace // create Stata mapfile

use data/world-d.dta
spmap using data/world-c.dta if NAME!="Antarctica", id(id1) point(d(data/latlon.dta) x(lon) y(lat)	)
	graph save figures/Fig1, replace
	graph export figures/Fig1.eps, replace



exit

